==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/config/lang/gl/lang.php <==
<?php
/**
 * Galicianlanguage file
 *
 * @author Medúlio <medulio@ciberirmandade.org>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Rodrigo Rega <rodrigorega@gmail.com>
 */
$lang['menu']                  = 'Opcións de Configuración';
$lang['error']                 = 'Configuración non actualizada debido a un valor inválido, por favor revisa os teus trocos e volta envialos de novo.
<br />O(s) valor(es) incorrecto(s) amosanse cinguidos por un borde vermello.';
$lang['updated']               = 'Configuración actualizada correctamente.';
$lang['nochoice']              = '(non hai outras escollas dispoñibles)';
$lang['locked']                = 'Non se puido actualizar o arquivo de configuración, se non ocorre como debería ser, <br />
asegúrate de que o nome do arquivo de configuración local e os permisos son correctos.';
$lang['danger']                = 'Perigo: mudando esta opción podes facer inaccesíbeis o teu wiki e máis o menú de configuración.';
$lang['warning']               = 'Ollo: mudando esta opción poden aparecer comportamentos do aplicativo non agardados.';
$lang['security']              = 'Aviso de seguranza: mudando esta opción poden aparecer riscos de seguranza.';
$lang['_configuration_manager'] = 'Xestor de Configuración';
$lang['_header_dokuwiki']      = 'Configuración do DokuWiki';
$lang['_header_plugin']        = 'Configuración de Extensións';
$lang['_header_template']      = 'Configuración de Sobreplanta';
$lang['_header_undefined']     = 'Configuración Indefinida';
$lang['_basic']                = 'Configuración Básica';
$lang['_display']              = 'Configuración de Visualización';
$lang['_authentication']       = 'Configuración de Autenticación';
$lang['_anti_spam']            = 'Configuración de Anti-Correo-lixo';
$lang['_editing']              = 'Configuración de Edición';
$lang['_links']                = 'Configuración de Ligazóns';
$lang['_media']                = 'Configuración de Media';
$lang['_notifications']        = 'Opcións de Notificación';
$lang['_syndication']          = 'Opcións de Sindicación';
$lang['_advanced']             = 'Configuración Avanzada';
$lang['_network']              = 'Configuración de Rede';
$lang['_plugin_sufix']         = 'Configuración de Extensións';
$lang['_template_sufix']       = 'Configuración de Sobreplanta';
$lang['_msg_setting_undefined'] = 'Non hai configuración de metadatos.';
$lang['_msg_setting_no_class'] = 'Non hai configuración de clase.';
$lang['_msg_setting_no_default'] = 'Non hai valor predeterminado.';
$lang['title']                 = 'Título do Wiki';
$lang['start']                 = 'Nome da páxina inicial';
$lang['lang']                  = 'Idioma';
$lang['template']              = 'Sobreplanta';
$lang['tagline']               = 'Tagline (si a plantilla o soporta)';
$lang['sidebar']               = 'Nome de páxina da barra lateral (si a platilla o soporta), o campo en baleiro deshabilita a barra lateral';
$lang['license']               = 'Baixo de que licenza será ceibado o teu contido?';
$lang['savedir']               = 'Directorio no que se gardarán os datos';
$lang['basedir']               = 'Directorio base';
$lang['baseurl']               = 'URL base';
$lang['cookiedir']             = 'Ruta das cookies. Deixar en blanco para usar a url de base.';
$lang['dmode']                 = 'Modo de creación de directorios';
$lang['fmode']                 = 'Modo de creación de arquivos';
$lang['allowdebug']            = 'Permitir o depurado <b>desactívao se non o precisas!</b>';
$lang['recent']                = 'Trocos recentes';
$lang['recent_days']           = 'Número de trocos recentes a manter (días)';
$lang['breadcrumbs']           = 'Número de niveis da estrutura de navegación';
$lang['youarehere']            = 'Niveis xerárquicos da estrutura de navegación';
$lang['fullpath']              = 'Amosar a ruta completa das páxinas no pé das mesmas';
$lang['typography']            = 'Facer substitucións tipográficas';
$lang['dformat']               = 'Formato de Data (bótalle un ollo á función <a href="http://www.php.net/strftime">strftime</a> do PHP)';
$lang['signature']             = 'Sinatura';
$lang['showuseras']            = 'Que amosar cando se informe do usuario que fixo a última modificación dunha páxina';
$lang['toptoclevel']           = 'Nivel superior para a táboa de contidos';
$lang['tocminheads']           = 'Cantidade mínima de liñas de cabeceira que determinará se a TDC vai ser xerada';
$lang['maxtoclevel']           = 'Nivel máximo para a táboa de contidos';
$lang['maxseclevel']           = 'Nivel máximo de edición da sección';
$lang['camelcase']             = 'Utilizar CamelCase para as ligazóns';
$lang['deaccent']              = 'Limpar nomes de páxina';
$lang['useheading']            = 'Utilizar a primeira cabeceira para os nomes de páxina';
$lang['sneaky_index']          = 'O DokuWiki amosará por defecto todos os nomes de espazo na vista de índice. Se activas isto agocharanse aqueles onde o usuario non teña permisos de lectura.';
$lang['hidepages']             = 'Agochar páxinas que coincidan (expresións regulares)';
$lang['useacl']                = 'Utilizar lista de control de acceso';
$lang['autopasswd']            = 'Xerar contrasinais automaticamente';
$lang['authtype']              = 'Backend de autenticación';
$lang['passcrypt']             = 'Método de encriptado do contrasinal';
$lang['defaultgroup']          = 'Grupo por defecto';
$lang['superuser']             = 'Super-usuario - un grupo ou usuario con acceso completo a todas as páxinas e funcións independentemente da configuración da ACL';
$lang['manager']               = 'Xestor - un grupo ou usuario con acceso a certas funcións de xestión';
$lang['profileconfirm']        = 'Confirmar trocos de perfil mediante contrasinal';
$lang['rememberme']            = 'Permitir cookies permanentes de inicio de sesión (lembrarme)';
$lang['disableactions']        = 'Desactivar accións do DokuWiki';
$lang['disableactions_check']  = 'Comprobar';
$lang['disableactions_subscription'] = 'Subscribir/Desubscribir';
$lang['disableactions_wikicode'] = 'Ver fonte/Exportar Datos Raw';
$lang['disableactions_other']  = 'Outras accións (separadas por comas)';
$lang['auth_security_timeout'] = 'Tempo Límite de Seguridade de Autenticación (segundos)';
$lang['securecookie']          = 'Deben enviarse só vía HTTPS polo navegador as cookies configuradas vía HTTPS? Desactiva esta opción cando só o inicio de sesión do teu wiki estea asegurado con SSL pero a navegación do mesmo se faga de xeito inseguro.';
$lang['remote']                = 'Permite o uso do sistema API remoto. Isto permite a outras aplicacións acceder ao wiki mediante XML-RPC ou outros mecanismos.';
$lang['remoteuser']            = 'Restrinxe o uso remoto da API aos grupos ou usuarios indicados, separados por comas. Deixar baleiro para dar acceso a todo o mundo.';
$lang['usewordblock']          = 'Bloquear correo-lixo segundo unha lista de verbas';
$lang['relnofollow']           = 'Utilizar rel="nofollow" nas ligazóns externas';
$lang['indexdelay']            = 'Retardo denantes de indexar (seg)';
$lang['mailguard']             = 'Ofuscar enderezos de correo-e';
$lang['iexssprotect']          = 'Comprobar arquivos subidos na procura de posíbel código JavaScript ou HTML malicioso';
$lang['usedraft']              = 'Gardar un borrador automaticamente no tempo da edición';
$lang['htmlok']                = 'Permitir a inserción de HTML';
$lang['phpok']                 = 'Permitir a inserción de PHP';
$lang['locktime']              = 'Tempo máximo para o bloqueo de arquivos (seg.)';
$lang['cachetime']             = 'Tempo máximo para a caché (seg.)';
$lang['target____wiki']        = 'Fiestra de destino para as ligazóns internas';
$lang['target____interwiki']   = 'Fiestra de destino para as ligazóns interwiki';
$lang['target____extern']      = 'Fiestra de destino para as ligazóns externas';
$lang['target____media']       = 'Fiestra de destino para as ligazóns de media';
$lang['target____windows']     = 'Fiestra de destino para as ligazóns de fiestras';
$lang['mediarevisions']        = 'Habilitar revisións dos arquivos-media?';
$lang['refcheck']              = 'Comprobar a referencia media';
$lang['refshow']               = 'Número de referencias media a amosar';
$lang['gdlib']                 = 'Versión da Libraría GD';
$lang['im_convert']            = 'Ruta deica a ferramenta de conversión ImageMagick';
$lang['jpg_quality']           = 'Calidade de compresión dos JPG (0-100)';
$lang['fetchsize']             = 'Tamaño máximo (en bytes) que pode descargar fetch.php dende fontes externas';
$lang['subscribers']           = 'Activar posibilidade de subscrición á páxina';
$lang['subscribe_time']        = 'Tempo despois do cal se enviarán os resumos e listas de subscrición (seg.): isto debe ser inferior ao tempo especificado en recent_days.';
$lang['notify']                = 'Enviar notificacións de trocos a este enderezo de correo-e';
$lang['registernotify']        = 'Enviar información de novos usuarios rexistrados a este enderezo de correo-e';
$lang['mailfrom']              = 'Enderezo de correo-e a usar para as mensaxes automáticas';
$lang['mailprefix']            = 'Prefixo de asunto de correo-e para as mensaxes automáticas';
$lang['htmlmail']              = 'Enviar correos electrónicos HTML multiparte máis estéticos, pero máis grande en tamaño. Deshabilitar para mandar correos electrónicos en texto claro.';
$lang['sitemap']               = 'Xerar mapa do sitio co Google (días)';
$lang['rss_type']              = 'Tipo de corrente RSS XML';
$lang['rss_linkto']            = 'A corrente XML liga para';
$lang['rss_content']           = 'Que queres amosar nos elementos da corrente XML?';
$lang['rss_update']            = 'Intervalo de actualización da corrente XML (seg.)';
$lang['rss_show_summary']      = 'Amosar sumario no título da corrente XML';
$lang['rss_media']             = 'Qué tipo de cambios deben ser listados no feed XML?';
$lang['updatecheck']           = 'Comprobar se hai actualizacións e avisos de seguridade? O DokuWiki precisa contactar con update.dokuwiki.org para executar esta característica.';
$lang['userewrite']            = 'Utilizar URLs amigábeis';
$lang['useslash']              = 'Utilizar a barra inclinada (/) como separador de nome de espazo nos URLs';
$lang['sepchar']               = 'Verba separadora do nome de páxina';
$lang['canonical']             = 'Utilizar URLs completamente canónicos';
$lang['fnencode']              = 'Método para codificar os nomes de arquivo non-ASCII.';
$lang['autoplural']            = 'Comprobar formas plurais nas ligazóns';
$lang['compression']           = 'Método de compresión para arquivos attic';
$lang['gzip_output']           = 'Utilizar Contido-Codificación gzip para o xhtml';
$lang['compress']              = 'Saída compacta de CSS e Javascript';
$lang['cssdatauri']            = 'Tamaño en bytes ata o cal as imaxes referenciadas nos CSS serán incrustadas na folla de estilos para disminuir o tamaño das cabeceiras das solicitudes HTTP. Esta técnica non funcionará en IE 7 ou anteriores! entre <code>400</code> e <code>600</code> bytes é un valor axeitado. Establecer a <code>0</code> para deshabilitar.';
$lang['send404']               = 'Enviar "HTTP 404/Páxina non atopada" para as páxinas inexistentes';
$lang['broken_iua']            = 'Rachou a función ignore_user_abort no teu sistema? Isto podería causar que o índice de procura non funcione. Coñécese que o IIS+PHP/CGI ráchaa. Bótalle un ollo ao <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> para obter máis información.';
$lang['xsendfile']             = 'Empregar a cabeceira X-Sendfile para que o servidor web envie arquivos estáticos? O teu servidor web precisa soportar isto.';
$lang['renderer_xhtml']        = 'Intérprete a empregar para a saída principal (XHTML) do Wiki';
$lang['renderer__core']        = '%s (núcleo do Dokuwiki)';
$lang['renderer__plugin']      = '%s (extensión)';
$lang['dnslookups']            = 'DokuWiki resolverá os nomes de host das direccións IP dos usuarios que editan as páxinas. Si contas un servidor DNS lento, que non funciona ou non che interesa esta característica, deshabilita esta opción';
$lang['proxy____host']         = 'Nome do servidor Proxy';
$lang['proxy____port']         = 'Porto do Proxy';
$lang['proxy____user']         = 'Nome de usuario do Proxy';
$lang['proxy____pass']         = 'Contrasinal do Proxy';
$lang['proxy____ssl']          = 'Utilizar ssl para conectar ao Proxy';
$lang['proxy____except']       = 'Expresión regular para atopar URLs que deban ser omitidas polo Proxy.';
$lang['safemodehack']          = 'Activar hack de modo seguro (safemode)';
$lang['ftp____host']           = 'Servidor FTP para o hack de modo seguro (safemode)';
$lang['ftp____port']           = 'Porto FTP para o hack de modo seguro(safemode)';
$lang['ftp____user']           = 'Nome de usuario FTP para o hack de modo seguro(safemode)';
$lang['ftp____pass']           = 'Contrasinal FTP para o hack de modo seguro(safemode)';
$lang['ftp____root']           = 'Directorio raigaña do FTP para o hack de modo seguro(safemode)';
$lang['license_o_']            = 'Non se escolleu nada';
$lang['typography_o_0']        = 'ningunha';
$lang['typography_o_1']        = 'Só dobres aspas';
$lang['typography_o_2']        = 'Todas as aspas (pode que non funcione sempre)';
$lang['userewrite_o_0']        = 'ningún';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'Interno do DokuWiki';
$lang['deaccent_o_0']          = 'desconectado';
$lang['deaccent_o_1']          = 'Eliminar acentos';
$lang['deaccent_o_2']          = 'romanizar';
$lang['gdlib_o_0']             = 'Libraría GD non dispoñíbel';
$lang['gdlib_o_1']             = 'Versión 1.x';
$lang['gdlib_o_2']             = 'Detección automática';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Sumario';
$lang['rss_content_o_diff']    = 'Formato Unified Diff';
$lang['rss_content_o_htmldiff'] = 'Táboa diff formatada en HTML';
$lang['rss_content_o_html']    = 'Contido HTML completo da páxina';
$lang['rss_linkto_o_diff']     = 'vista de diferenzas';
$lang['rss_linkto_o_page']     = 'a páxina revisada';
$lang['rss_linkto_o_rev']      = 'listaxe de revisións';
$lang['rss_linkto_o_current']  = 'a páxina actual';
$lang['compression_o_0']       = 'ningunha';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'non o empregues';
$lang['xsendfile_o_1']         = 'Cabeceira lighttpd propietaria (denantes da versión 1.5)';
$lang['xsendfile_o_2']         = 'Cabeceira X-Sendfile estándar';
$lang['xsendfile_o_3']         = 'Cabeceira X-Accel-Redirect propia de Nginx';
$lang['showuseras_o_loginname'] = 'Nome de inicio de sesión';
$lang['showuseras_o_username'] = 'Nome completo do usuario';
$lang['showuseras_o_email']    = 'Enderezo de correo-e do usuario (ofuscado segundo a configuración mailguard)';
$lang['showuseras_o_email_link'] = 'Enderezo de correo-e do usuario como ligazón mailto:';
$lang['useheading_o_0']        = 'Endexamais';
$lang['useheading_o_navigation'] = 'Só Navegación';
$lang['useheading_o_content']  = 'Só Contido do Wiki';
$lang['useheading_o_1']        = 'Sempre';
$lang['readdircache']          = 'Edad máxima para o directorio de caché (seg)';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/config/lang/gl/lang.php <==
<?php
/**
 * Galicianlanguage file
 *
 * @author Medúlio <medulio@ciberirmandade.org>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Rodrigo Rega <rodrigorega@gmail.com>
 */
$lang['menu']                  = 'Opcións de Configuración';
$lang['error']                 = 'Configuración non actualizada debido a un valor inválido, por favor revisa os teus trocos e volta envialos de novo.
<br />O(s) valor(es) incorrecto(s) amosanse cinguidos por un borde vermello.';
$lang['updated']               = 'Configuración actualizada correctamente.';
$lang['nochoice']              = '(non hai outras escollas dispoñibles)';
$lang['locked']                = 'Non se puido actualizar o arquivo de configuración, se non ocorre como debería ser, <br />
asegúrate de que o nome do arquivo de configuración local e os permisos son correctos.';
$lang['danger']                = 'Perigo: mudando esta opción podes facer inaccesíbeis o teu wiki e máis o menú de configuración.';
$lang['warning']               = 'Ollo: mudando esta opción poden aparecer comportamentos do aplicativo non agardados.';
$lang['security']              = 'Aviso de seguranza: mudando esta opción poden aparecer riscos de seguranza.';
$lang['_configuration_manager'] = 'Xestor de Configuración';
$lang['_header_dokuwiki']      = 'Configuración do DokuWiki';
$lang['_header_plugin']        = 'Configuración de Extensións';
$lang['_header_template']      = 'Configuración de Sobreplanta';
$lang['_header_undefined']     = 'Configuración Indefinida';
$lang['_basic']                = 'Configuración Básica';
$lang['_display']              = 'Configuración de Visualización';
$lang['_authentication']       = 'Configuración de Autenticación';
$lang['_anti_spam']            = 'Configuración de Anti-Correo-lixo';
$lang['_editing']              = 'Configuración de Edición';
$lang['_links']                = 'Configuración de Ligazóns';
$lang['_media']                = 'Configuración de Media';
$lang['_notifications']        = 'Opcións de Notificación';
$lang['_syndication']          = 'Opcións de Sindicación';
$lang['_advanced']             = 'Configuración Avanzada';
$lang['_network']              = 'Configuración de Rede';
$lang['_msg_setting_undefined'] = 'Non hai configuración de metadatos.';
$lang['_msg_setting_no_class'] = 'Non hai configuración de clase.';
$lang['_msg_setting_no_default'] = 'Non hai valor predeterminado.';
$lang['title']                 = 'Título do Wiki';
$lang['start']                 = 'Nome da páxina inicial';
$lang['lang']                  = 'Idioma';
$lang['template']              = 'Sobreplanta';
$lang['tagline']               = 'Tagline (si a plantilla o soporta)';
$lang['sidebar']               = 'Nome de páxina da barra lateral (si a platilla o soporta), o campo en baleiro deshabilita a barra lateral';
$lang['license']               = 'Baixo de que licenza será ceibado o teu contido?';
$lang['savedir']               = 'Directorio no que se gardarán os datos';
$lang['basedir']               = 'Directorio base';
$lang['baseurl']               = 'URL base';
$lang['cookiedir']             = 'Ruta das cookies. Deixar en blanco para usar a url de base.';
$lang['dmode']                 = 'Modo de creación de directorios';
$lang['fmode']                 = 'Modo de creación de arquivos';
$lang['allowdebug']            = 'Permitir o depurado <b>desactívao se non o precisas!</b>';
$lang['recent']                = 'Trocos recentes';
$lang['recent_days']           = 'Número de trocos recentes a manter (días)';
$lang['breadcrumbs']           = 'Número de niveis da estrutura de navegación';
$lang['youarehere']            = 'Niveis xerárquicos da estrutura de navegación';
$lang['fullpath']              = 'Amosar a ruta completa das páxinas no pé das mesmas';
$lang['typography']            = 'Facer substitucións tipográficas';
$lang['dformat']               = 'Formato de Data (bótalle un ollo á función <a href="http://php.net/strftime">strftime</a> do PHP)';
$lang['signature']             = 'Sinatura';
$lang['showuseras']            = 'Que amosar cando se informe do usuario que fixo a última modificación dunha páxina';
$lang['toptoclevel']           = 'Nivel superior para a táboa de contidos';
$lang['tocminheads']           = 'Cantidade mínima de liñas de cabeceira que determinará se a TDC vai ser xerada';
$lang['maxtoclevel']           = 'Nivel máximo para a táboa de contidos';
$lang['maxseclevel']           = 'Nivel máximo de edición da sección';
$lang['camelcase']             = 'Utilizar CamelCase para as ligazóns';
$lang['deaccent']              = 'Limpar nomes de páxina';
$lang['useheading']            = 'Utilizar a primeira cabeceira para os nomes de páxina';
$lang['sneaky_index']          = 'O DokuWiki amosará por defecto todos os nomes de espazo na vista de índice. Se activas isto agocharanse aqueles onde o usuario non teña permisos de lectura.';
$lang['hidepages']             = 'Agochar páxinas que coincidan (expresións regulares)';
$lang['useacl']                = 'Utilizar lista de control de acceso';
$lang['autopasswd']            = 'Xerar contrasinais automaticamente';
$lang['authtype']              = 'Backend de autenticación';
$lang['passcrypt']             = 'Método de encriptado do contrasinal';
$lang['defaultgroup']          = 'Grupo por defecto';
$lang['superuser']             = 'Super-usuario - un grupo ou usuario con acceso completo a todas as páxinas e funcións independentemente da configuración da ACL';
$lang['manager']               = 'Xestor - un grupo ou usuario con acceso a certas funcións de xestión';
$lang['profileconfirm']        = 'Confirmar trocos de perfil mediante contrasinal';
$lang['rememberme']            = 'Permitir cookies permanentes de inicio de sesión (lembrarme)';
$lang['disableactions']        = 'Desactivar accións do DokuWiki';
$lang['disableactions_check']  = 'Comprobar';
$lang['disableactions_subscription'] = 'Subscribir/Desubscribir';
$lang['disableactions_wikicode'] = 'Ver fonte/Exportar Datos Raw';
$lang['disableactions_other']  = 'Outras accións (separadas por comas)';
$lang['auth_security_timeout'] = 'Tempo Límite de Seguridade de Autenticación (segundos)';
$lang['securecookie']          = 'Deben enviarse só vía HTTPS polo navegador as cookies configuradas vía HTTPS? Desactiva esta opción cando só o inicio de sesión do teu wiki estea asegurado con SSL pero a navegación do mesmo se faga de xeito inseguro.';
$lang['remote']                = 'Permite o uso do sistema API remoto. Isto permite a outras aplicacións acceder ao wiki mediante XML-RPC ou outros mecanismos.';
$lang['remoteuser']            = 'Restrinxe o uso remoto da API aos grupos ou usuarios indicados, separados por comas. Deixar baleiro para dar acceso a todo o mundo.';
$lang['usewordblock']          = 'Bloquear correo-lixo segundo unha lista de verbas';
$lang['relnofollow']           = 'Utilizar rel="nofollow" nas ligazóns externas';
$lang['indexdelay']            = 'Retardo denantes de indexar (seg)';
$lang['mailguard']             = 'Ofuscar enderezos de correo-e';
$lang['iexssprotect']          = 'Comprobar arquivos subidos na procura de posíbel código JavaScript ou HTML malicioso';
$lang['usedraft']              = 'Gardar un borrador automaticamente no tempo da edición';
$lang['locktime']              = 'Tempo máximo para o bloqueo de arquivos (seg.)';
$lang['cachetime']             = 'Tempo máximo para a caché (seg.)';
$lang['target____wiki']        = 'Fiestra de destino para as ligazóns internas';
$lang['target____interwiki']   = 'Fiestra de destino para as ligazóns interwiki';
$lang['target____extern']      = 'Fiestra de destino para as ligazóns externas';
$lang['target____media']       = 'Fiestra de destino para as ligazóns de media';
$lang['target____windows']     = 'Fiestra de destino para as ligazóns de fiestras';
$lang['mediarevisions']        = 'Habilitar revisións dos arquivos-media?';
$lang['refcheck']              = 'Comprobar a referencia media';
$lang['gdlib']                 = 'Versión da Libraría GD';
$lang['im_convert']            = 'Ruta deica a ferramenta de conversión ImageMagick';
$lang['jpg_quality']           = 'Calidade de compresión dos JPG (0-100)';
$lang['fetchsize']             = 'Tamaño máximo (en bytes) que pode descargar fetch.php dende fontes externas';
$lang['subscribers']           = 'Activar posibilidade de subscrición á páxina';
$lang['subscribe_time']        = 'Tempo despois do cal se enviarán os resumos e listas de subscrición (seg.): isto debe ser inferior ao tempo especificado en recent_days.';
$lang['notify']                = 'Enviar notificacións de trocos a este enderezo de correo-e';
$lang['registernotify']        = 'Enviar información de novos usuarios rexistrados a este enderezo de correo-e';
$lang['mailfrom']              = 'Enderezo de correo-e a usar para as mensaxes automáticas';
$lang['mailprefix']            = 'Prefixo de asunto de correo-e para as mensaxes automáticas';
$lang['htmlmail']              = 'Enviar correos electrónicos HTML multiparte máis estéticos, pero máis grande en tamaño. Deshabilitar para mandar correos electrónicos en texto claro.';
$lang['sitemap']               = 'Xerar mapa do sitio co Google (días)';
$lang['rss_type']              = 'Tipo de corrente RSS XML';
$lang['rss_linkto']            = 'A corrente XML liga para';
$lang['rss_content']           = 'Que queres amosar nos elementos da corrente XML?';
$lang['rss_update']            = 'Intervalo de actualización da corrente XML (seg.)';
$lang['rss_show_summary']      = 'Amosar sumario no título da corrente XML';
$lang['rss_media']             = 'Qué tipo de cambios deben ser listados no feed XML?';
$lang['updatecheck']           = 'Comprobar se hai actualizacións e avisos de seguridade? O DokuWiki precisa contactar con update.dokuwiki.org para executar esta característica.';
$lang['userewrite']            = 'Utilizar URLs amigábeis';
$lang['useslash']              = 'Utilizar a barra inclinada (/) como separador de nome de espazo nos URLs';
$lang['sepchar']               = 'Verba separadora do nome de páxina';
$lang['canonical']             = 'Utilizar URLs completamente canónicos';
$lang['fnencode']              = 'Método para codificar os nomes de arquivo non-ASCII.';
$lang['autoplural']            = 'Comprobar formas plurais nas ligazóns';
$lang['compression']           = 'Método de compresión para arquivos attic';
$lang['gzip_output']           = 'Utilizar Contido-Codificación gzip para o xhtml';
$lang['compress']              = 'Saída compacta de CSS e Javascript';
$lang['cssdatauri']            = 'Tamaño en bytes ata o cal as imaxes referenciadas nos CSS serán incrustadas na folla de estilos para disminuir o tamaño das cabeceiras das solicitudes HTTP. Entre <code>400</code> e <code>600</code> bytes é un valor axeitado. Establecer a <code>0</code> para deshabilitar.';
$lang['send404']               = 'Enviar "HTTP 404/Páxina non atopada" para as páxinas inexistentes';
$lang['broken_iua']            = 'Rachou a función ignore_user_abort no teu sistema? Isto podería causar que o índice de procura non funcione. Coñécese que o IIS+PHP/CGI ráchaa. Bótalle un ollo ao <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> para obter máis información.';
$lang['xsendfile']             = 'Empregar a cabeceira X-Sendfile para que o servidor web envie arquivos estáticos? O teu servidor web precisa soportar isto.';
$lang['renderer_xhtml']        = 'Intérprete a empregar para a saída principal (XHTML) do Wiki';
$lang['renderer__core']        = '%s (núcleo do Dokuwiki)';
$lang['renderer__plugin']      = '%s (extensión)';
$lang['dnslookups']            = 'DokuWiki resolverá os nomes de host das direccións IP dos usuarios que editan as páxinas. Si contas un servidor DNS lento, que non funciona ou non che interesa esta característica, deshabilita esta opción';
$lang['proxy____host']         = 'Nome do servidor Proxy';
$lang['proxy____port']         = 'Porto do Proxy';
$lang['proxy____user']         = 'Nome de usuario do Proxy';
$lang['proxy____pass']         = 'Contrasinal do Proxy';
$lang['proxy____ssl']          = 'Utilizar ssl para conectar ao Proxy';
$lang['proxy____except']       = 'Expresión regular para atopar URLs que deban ser omitidas polo Proxy.';
$lang['license_o_']            = 'Non se escolleu nada';
$lang['typography_o_0']        = 'ningunha';
$lang['typography_o_1']        = 'Só dobres aspas';
$lang['typography_o_2']        = 'Todas as aspas (pode que non funcione sempre)';
$lang['userewrite_o_0']        = 'ningún';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'Interno do DokuWiki';
$lang['deaccent_o_0']          = 'desconectado';
$lang['deaccent_o_1']          = 'Eliminar acentos';
$lang['deaccent_o_2']          = 'romanizar';
$lang['gdlib_o_0']             = 'Libraría GD non dispoñíbel';
$lang['gdlib_o_1']             = 'Versión 1.x';
$lang['gdlib_o_2']             = 'Detección automática';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Sumario';
$lang['rss_content_o_diff']    = 'Formato Unified Diff';
$lang['rss_content_o_htmldiff'] = 'Táboa diff formatada en HTML';
$lang['rss_content_o_html']    = 'Contido HTML completo da páxina';
$lang['rss_linkto_o_diff']     = 'vista de diferenzas';
$lang['rss_linkto_o_page']     = 'a páxina revisada';
$lang['rss_linkto_o_rev']      = 'listaxe de revisións';
$lang['rss_linkto_o_current']  = 'a páxina actual';
$lang['compression_o_0']       = 'ningunha';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'non o empregues';
$lang['xsendfile_o_1']         = 'Cabeceira lighttpd propietaria (denantes da versión 1.5)';
$lang['xsendfile_o_2']         = 'Cabeceira X-Sendfile estándar';
$lang['xsendfile_o_3']         = 'Cabeceira X-Accel-Redirect propia de Nginx';
$lang['showuseras_o_loginname'] = 'Nome de inicio de sesión';
$lang['showuseras_o_username'] = 'Nome completo do usuario';
$lang['showuseras_o_email']    = 'Enderezo de correo-e do usuario (ofuscado segundo a configuración mailguard)';
$lang['showuseras_o_email_link'] = 'Enderezo de correo-e do usuario como ligazón mailto:';
$lang['useheading_o_0']        = 'Endexamais';
$lang['useheading_o_navigation'] = 'Só Navegación';
$lang['useheading_o_content']  = 'Só Contido do Wiki';
$lang['useheading_o_1']        = 'Sempre';
$lang['readdircache']          = 'Edad máxima para o directorio de caché (seg)';
